==> fxt-2006.06.22.tgz: fxt/demo/ds/orderedrarray-demo.cc <==

#include "ds/orderedrarray.h"
#include "ds/rarray.h"

#include "fxttypes.h"
#include "fxtiomanip.h"
#include "jjassert.h"

#include <cstdlib> // atol()

//% Demo of the resizable array data structure.

static void
print_ordered_rarray(ordered_rarray<ulong> &f)
{
    cout << "  ";
    ulong *x = f.data();
    ulong k=0;
    for (  ; k<f.n(); ++k)
    {
        cout << setw(3) << x[k];
    }
    for (  ; k<f.size(); ++k)
    {
        cout << setw(3) << "-";
    }

    cout << "   #=" << setw(1) << f.n();
    cout << endl;
}
// -------------------------

static void
vinsert(ordered_rarray<ulong> &f, ulong k)
{
    k = k/3 + (k&1?k/2:0);
    ulong n = f.insert(k);
    if ( 0==n )  cout << "  FAILED  ";
    cout << "insert(" << setw(2) << k << ")";
    print_ordered_rarray(f);
}
// -------------------------

static void
vremove(ordered_rarray<ulong> &f)
{
    ulong n = f.n();
    ulong j = n/2;
//    ulong z = f.get(j);
    f.remove_at(j);
    cout << "remove @" << setw(2) << j << "";
    print_ordered_rarray(f);
    if ( 0==n )  cout << "  (ordered_rarray was empty)  " << endl;
//    if ( n )  { jjassert( z ); }
}
// -------------------------

int
main(int argc, char **argv)
{
    ulong n = 4;
    if ( argc>1 )  n = atol(argv[1]);

    ordered_rarray<ulong> f(n, n);

    ulong k = 1;
    for (  ; k<2*n; ++k)
    {
        vinsert(f, k);
    }

    for (  ; k<4*n; ++k)
    {
        vremove(f);
        vremove(f);
        vinsert(f, k);
    }

    return 0;
}
// -------------------------

==> fxt-2008.02.02.tgz: fxt/demo/ds/orderedrarray-demo.cc <==

#include "ds/orderedrarray.h"
#include "ds/rarray.h"

#include "fxttypes.h"
#include "fxtiomanip.h"
#include "jjassert.h"

#include <cstdlib> // atol()

//% Demo of the resizable array data structure.

static void
print_ordered_rarray(ordered_rarray<ulong> &f)
{
    cout << "  ";
    ulong *x = f.data();
    ulong k=0;
    for (  ; k<f.num(); ++k)
    {
        cout << setw(3) << x[k];
    }
    for (  ; k<f.size(); ++k)
    {
        cout << setw(3) << "-";
    }

    cout << "   #=" << setw(1) << f.num();
    cout << endl;
}
// -------------------------

static void
vinsert(ordered_rarray<ulong> &f, ulong k)
{
    k = k/3 + (k&1?k/2:0);
    ulong n = f.insert(k);
    if ( 0==n )  cout << "  FAILED  ";
    cout << "insert(" << setw(2) << k << ")";
    print_ordered_rarray(f);
}
// -------------------------

static void
vremove(ordered_rarray<ulong> &f)
{
    ulong n = f.num();
    ulong j = n/2;
//    ulong z = f.get(j);
    f.remove_at(j);
    cout << "remove @" << setw(2) << j << "";
    print_ordered_rarray(f);
    if ( 0==n )  cout << "  (ordered_rarray was empty)  " << endl;
//    if ( n )  { jjassert( z ); }
}
// -------------------------

int
main(int argc, char **argv)
{
    ulong n = 4;
    if ( argc>1 )  n = atol(argv[1]);

    ordered_rarray<ulong> f(n, n);

    ulong k = 1;
    for (  ; k<2*n; ++k)
    {
        vinsert(f, k);
    }

    for (  ; k<4*n; ++k)
    {
        vremove(f);
        vremove(f);
        vinsert(f, k);
    }

    return 0;
}
// -------------------------


/// Emacs:
/// Local Variables:
/// MyRelDir: "demo/ds"
/// makefile-dir: "../../"
/// make-target: "1demo DSRC=demo/ds/orderedrarray-demo.cc"
/// End:
